@@ -248,103 +248,111 @@ class dyagram:
     def discover_routes_ssh(self, device):
 
         # CONN_SET = False
+        try:
 
+            os = self.get_device_type(device)
 
-        os = self.get_device_type(device)
+            netmiko_args = {"device_type": os,
+                            "host": device,
+                            "username": self.username,
+                            "password": self.password,
+                            "secret": self.password,
+                            "banner_timeout": 200
+                            }
+            # autodetect_tries = 0
+            # while autodetect_tries < 10:
+            #     try:
+            #         guesser = SSHDetect(**autodetect_netmiko_args)
+            #         best_match = guesser.autodetect()
+            #         netmiko_args['device_type'] = best_match
+            #
+            #         dev = ConnectHandler(**netmiko_args)
+            #         dev.enable()
+            #
+            #
+            #
+            #     except NetmikoAuthenticationException:
+            #         # print(f"AUTHENTICATION ERROR FOR DEVICE: {device}")
+            #         return False
+            #     except:
+            #         autodetect_tries += 1
+            #         time.sleep(5)
+            #         tb = self.get_traceback()
+            #         self.log.info(f"DEVICE: {device} EXCEPTION02 THROWN IN discover_routes_ssh: {tb}")
 
-        netmiko_args = {"device_type": os,
-                        "host": device,
-                        "username": self.username,
-                        "password": self.password,
-                        "secret": self.password,
-                        "banner_timeout": 200
-                        }
-        # autodetect_tries = 0
-        # while autodetect_tries < 10:
-        #     try:
-        #         guesser = SSHDetect(**autodetect_netmiko_args)
-        #         best_match = guesser.autodetect()
-        #         netmiko_args['device_type'] = best_match
-        #
-        #         dev = ConnectHandler(**netmiko_args)
-        #         dev.enable()
-        #
-        #
-        #
-        #     except NetmikoAuthenticationException:
-        #         # print(f"AUTHENTICATION ERROR FOR DEVICE: {device}")
-        #         return False
-        #     except:
-        #         autodetect_tries += 1
-        #         time.sleep(5)
-        #         tb = self.get_traceback()
-        #         self.log.info(f"DEVICE: {device} EXCEPTION02 THROWN IN discover_routes_ssh: {tb}")
+                # raise Exception("Unable to determine OS or OS Not Supported.")
+            #     try:
+            #         if not netmiko_args['device_type']:
+            #             # Later put in unable to find OS
+            #             netmiko_args['device_type'] = "cisco_ios"
+            #         dev = ConnectHandler(**netmiko_args)
+            #         dev.enable()
+            #         CONN_SET = True
+            #     except Exception:
+            #         tb = self.get_traceback()
+            #         self.log.info(f"DEVICE: {device} EXCEPTION THROWN IN discover_routes_ssh: {tb}")
+            #
+            #         # print(tb)
+            #
+            #
+            # os = self._get_os_version(dev)
+            # netmiko_args['device_type'] = os
 
-            # raise Exception("Unable to determine OS or OS Not Supported.")
-        #     try:
-        #         if not netmiko_args['device_type']:
-        #             # Later put in unable to find OS
-        #             netmiko_args['device_type'] = "cisco_ios"
-        #         dev = ConnectHandler(**netmiko_args)
-        #         dev.enable()
-        #         CONN_SET = True
-        #     except Exception:
-        #         tb = self.get_traceback()
-        #         self.log.info(f"DEVICE: {device} EXCEPTION THROWN IN discover_routes_ssh: {tb}")
-        #
-        #         # print(tb)
-        #
-        #
-        # os = self._get_os_version(dev)
-        # netmiko_args['device_type'] = os
+            # if not CONN_SET:
+            #     dev = ConnectHandler(**netmiko_args)
 
-        # if not CONN_SET:
-        #     dev = ConnectHandler(**netmiko_args)
+            dev = ConnectHandler(**netmiko_args)
+            dev.enable()
 
-        dev = ConnectHandler(**netmiko_args)
-        dev.enable()
+            routes = dev.send_command("show ip route vrf all", use_textfsm=True)
 
-        routes = dev.send_command("show ip route vrf all", use_textfsm=True)
+            for route in routes:
+                if 'uptime' in route.keys():
+                    route.pop('uptime')
 
-        for route in routes:
-            if 'uptime' in route.keys():
-                route.pop('uptime')
+            dev.disconnect()
+            for i in self.topology['devices']:
+                if i['inventory_ip'] == device:
+                    i['routes'] = routes
+                    break
+        except:
+            tb = self.get_traceback()
+            self.log.info(f"DEVICE: {device} EXCEPTION THROWN IN discover_routes_ssh: {tb}")
 
-        dev.disconnect()
-        for i in self.topology['devices']:
-            if i['inventory_ip'] == device:
-                i['routes'] = routes
-                break
 
     def get_device_type(self, device):
 
-        autodetect_netmiko_args = {"device_type": "autodetect",
-                                   "host": device,
-                                   "username": self.username,
-                                   "password": self.password,
-                                   "banner_timeout": 200}
-        autodetect_tries = 0
-        while autodetect_tries < 10:
-            try:
+        try:
 
-                guesser = SSHDetect(**autodetect_netmiko_args)
-                best_match = guesser.autodetect()
-                return best_match
+            autodetect_netmiko_args = {"device_type": "autodetect",
+                                       "host": device,
+                                       "username": self.username,
+                                       "password": self.password,
+                                       "banner_timeout": 200}
+            autodetect_tries = 0
+            while autodetect_tries < 10:
+                try:
+
+                    guesser = SSHDetect(**autodetect_netmiko_args)
+                    best_match = guesser.autodetect()
+                    return best_match
 
 
-            except NetmikoAuthenticationException:
-                # print(f"AUTHENTICATION ERROR FOR DEVICE: {device}")
-                return None
+                except NetmikoAuthenticationException:
+                    # print(f"AUTHENTICATION ERROR FOR DEVICE: {device}")
+                    return None
 
-            except:
-
-                if autodetect_tries > 10:
-                    tb = self.get_traceback()
-                    self.log.info(f"DEVICE: {device} EXCEPTION THROWN IN GET_DEVICE_TYPE: {tb}")
-                    raise Exception("Unable to access device")
-                autodetect_tries += 1
-                time.sleep(5)
+                except:
 
+                    if autodetect_tries > 10:
+                        tb = self.get_traceback()
+                        self.log.info(f"DEVICE: {device} EXCEPTION THROWN IN GET_DEVICE_TYPE: {tb}")
+                        raise Exception("Unable to access device")
+                    autodetect_tries += 1
+                    time.sleep(5)
+        except:
+            tb = self.get_traceback()
+            self.log.info(f"DEVICE: {device} EXCEPTION THROWN IN get_device_type: {tb}")
 
 
 
@@ -356,9 +364,9 @@ class dyagram:
 
             self.discover_eigrp_neighbors(device)
 
-            self.discover_ospf_neighbors(device)
-
-            self.discover_bgp_neighbors(device)
+            # self.discover_ospf_neighbors(device)
+            #
+            # self.discover_bgp_neighbors(device)
 
             self.pbar.update(self.pbar_update_int)
         except:
@@ -392,7 +400,8 @@ class dyagram:
             else:
                 self.log.info(f"DEVICE: {device} - RESTCONF : Discovering EIGRP Neighbors - SUCCESS")
         except:
-            pass
+            tb = self.get_traceback()
+            self.log.info(f"DEVICE: {device} - SSH : ERROR discover_eigrp_neighbors - {tb}")
 
 
     def discover_eigrp_neighbors_restconf(self):
@@ -480,65 +489,71 @@ class dyagram:
         return True
 
     def _discover_lldp_neighbors_by_ssh(self, device):
-        self.log.info(f"DEVICE: {device} - SSH : STARTING MODULE: _discover_lldp_neighbors_by_ssh")
-
-        os = self.get_device_type(device)
-
-        netmiko_args = {"device_type": os,
-                        "host": device,
-                        "username": self.username,
-                        "password": self.password,
-                        "secret": self.password,
-                        "banner_timeout": 200}
-
-
-            # try:
-            #     if not netmiko_args['device_type']:
-            #         # Later put in unable to find OS
-            #         netmiko_args['device_type'] = "cisco_ios"
-            #     dev = ConnectHandler(**netmiko_args)
-            #     dev.enable()
-            # except Exception:
-            #     tb = self.get_traceback()
-            #     self.log.info(f"DEVICE: {device} - SSH : ERROR DISCOVER LLDP NEIGHBORS - {tb}")
-
-
-            # CONN_SET = True
-            # os = self._get_os_version(dev)
-            # netmiko_args['device_type'] = os
-
-
-        dev = ConnectHandler(**netmiko_args)
-
-        self.log.info(f"DEVICE: {device} - SSH : SETTING ENABLE")
-
-        dev.enable()
-        self.log.info(f"DEVICE: {device} - SSH : ENABLE SET")
 
         try:
-            lldp_nei_json = self._get_lldp_neighbors_ssh_textfsm(dev)
+            self.log.info(f"DEVICE: {device} - SSH : STARTING MODULE: _discover_lldp_neighbors_by_ssh")
+
+            os = self.get_device_type(device)
+
+            netmiko_args = {"device_type": os,
+                            "host": device,
+                            "username": self.username,
+                            "password": self.password,
+                            "secret": self.password,
+                            "banner_timeout": 200}
+
+
+                # try:
+                #     if not netmiko_args['device_type']:
+                #         # Later put in unable to find OS
+                #         netmiko_args['device_type'] = "cisco_ios"
+                #     dev = ConnectHandler(**netmiko_args)
+                #     dev.enable()
+                # except Exception:
+                #     tb = self.get_traceback()
+                #     self.log.info(f"DEVICE: {device} - SSH : ERROR DISCOVER LLDP NEIGHBORS - {tb}")
+
+
+                # CONN_SET = True
+                # os = self._get_os_version(dev)
+                # netmiko_args['device_type'] = os
+
+
+            dev = ConnectHandler(**netmiko_args)
+
+            self.log.info(f"DEVICE: {device} - SSH : SETTING ENABLE")
+
+            dev.enable()
+            self.log.info(f"DEVICE: {device} - SSH : ENABLE SET")
 
-            if type(lldp_nei_json) == str:
-                raise ValueError("LLDP NEIGHBORS ARE STRs. Try without textfsm")
-        except ValueError as e:
             try:
-                lldp_nei_json = self._get_lldp_neighbors_ssh_regex(dev)
-            except:
+                lldp_nei_json = self._get_lldp_neighbors_ssh_textfsm(dev)
+
+                if type(lldp_nei_json) == str:
+                    raise ValueError("LLDP NEIGHBORS ARE STRs. Try without textfsm")
+            except ValueError as e:
+                try:
+                    lldp_nei_json = self._get_lldp_neighbors_ssh_regex(dev)
+                except:
+                    tb = self.get_traceback()
+                    self.log.info(f"DEVICE: {device} EXCEPTION22 IN _discover_lldp_neighbors_by_ssh: {tb}")
+            except Exception:
                 tb = self.get_traceback()
-                self.log.info(f"DEVICE: {device} EXCEPTION22 IN _discover_lldp_neighbors_by_ssh: {tb}")
-        except Exception:
+                self.log.info(f"DEVICE: {device} - SSH : ERROR DISCOVER LLDP NEIGHBORS - {tb}")
+
+            for i in self.topology["devices"]:
+                if i['inventory_ip'] == device:
+                    i['hostname'] = lldp_nei_json['hostname']
+                    lldp_nei_json.pop("hostname")
+                    i['layer2'] = lldp_nei_json
+                    break
+
+            dev.disconnect()
+            self._devices_queried.append(device)
+        except:
             tb = self.get_traceback()
-            self.log.info(f"DEVICE: {device} - SSH : ERROR DISCOVER LLDP NEIGHBORS - {tb}")
+            self.log.info(f"EXCEPTION01 THROWN IN _discover_lldp_neighbors_by_ssh : {tb}")
 
-        for i in self.topology["devices"]:
-            if i['inventory_ip'] == device:
-                i['hostname'] = lldp_nei_json['hostname']
-                lldp_nei_json.pop("hostname")
-                i['layer2'] = lldp_nei_json
-                break
-
-        dev.disconnect()
-        self._devices_queried.append(device)
 
     def _create_netmiko_session(self, netmiko_kargs):
 
